From 75bde1b8b1d46a2a5e5c20d1c22d362b2b8510dd Mon Sep 17 00:00:00 2001
From: wyrie <wyrie@ispconfig3>
Date: Mon, 11 Oct 2010 04:55:12 -0400
Subject: [PATCH] Helper script Bug fix updated layman path • Bug fix include soap flag when installing php for web • Bug fix use flags duplicated in is_package_installed • Bug fix checking for mysql emerged line 543 • Bug fix substring match for quota package • Improved use flag detection • Moved layman install to meta_web as it's only required for jailkit • Added prompt for courier or dovecot • Added baselayout check • Added apache module checks and configuration • Added packages awstats & mod_ruby
---
interface/web/mail/mail_get_list.php | 7 ++-----
1 files changed, 2 insertions(+), 5 deletions(-)
diff --git a/interface/web/mail/mail_get_list.php b/interface/web/mail/mail_get_list.php
index 55300d3..f485058 100644
--- a/interface/web/mail/mail_get_list.php
+++ b/interface/web/mail/mail_get_list.php
@@ -12,11 +12,8 @@
* End Form configuration
******************************************/
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],$_SESSION["s"]["module"]["name"])) {
- header("Location: ../index.php");
- exit;
-}
+//* Check permissions for module
+$app->auth->check_module_permissions('mail');
$app->uses('listform_actions');
--
Gitblit v1.9.1